@@ -5,7 +5,7 @@
 # Global variables
 if (getRversion() >= "2.15.1") {
   utils::globalVariables(c("brow",
-                           "dat", "dat2", "results", "plot_group", "heat.colors", "results", "dev.new"))
+                           "dat", "dat2", "trat", "results", "plot_group", "heat.colors", "results", "dev.new"))
 }
 
 
